Learn R Programming

treasuryTR (version 0.1.6)

tibble_to_xts: Convert a tibble data frame to an xts object

Description

Convert a tibble data frame to an xts object

Usage

tibble_to_xts(x)

Value

An xts object

Arguments

x

a tibble with a column 'date'